@@ -188,6 +188,9 @@ pub struct Stop {
     /// Transfers from this Stop
     #[serde(skip)]
     pub transfers: Vec<StopTransfer>,
+    /// Pathways from this stop
+    #[serde(skip)]
+    pub pathways: Vec<Pathway>,
 }
 
 impl Type for Stop {
@@ -255,7 +258,7 @@ pub struct RawStopTime {
 }
 
 /// The moment where a vehicle, running on [Trip] stops at a [Stop]. See <https://gtfs.org/reference/static/#stopstxt>
-#[derive(Debug, Default)]
+#[derive(Clone, Debug, Default)]
 pub struct StopTime {
     /// Arrival time of the stop time.
     /// It's an option since the intermediate stops can have have no arrival
@@ -326,23 +329,25 @@ pub struct Route {
     pub url: Option<String>,
     /// Agency for the specified route
     pub agency_id: Option<String>,
-    #[serde(rename = "route_sort_order")]
     /// Orders the routes in a way which is ideal for presentation to customers. Routes with smaller route_sort_order values should be displayed first.
-    pub route_order: Option<u32>,
+    #[serde(rename = "route_sort_order")]
+    pub order: Option<u32>,
     /// Route color designation that matches public facing material
     #[serde(
-        deserialize_with = "de_with_optional_color",
-        serialize_with = "serialize_optional_color",
-        default
+        deserialize_with = "deserialize_color",
+        serialize_with = "serialize_color",
+        rename = "route_color",
+        default = "default_route_color"
     )]
-    pub route_color: Option<RGB8>,
+    pub color: RGB8,
     /// Legible color to use for text drawn against a background of [Route::route_color]
     #[serde(
-        deserialize_with = "de_with_optional_color",
-        serialize_with = "serialize_optional_color",
+        deserialize_with = "deserialize_color",
+        serialize_with = "serialize_color",
+        rename = "route_text_color",
         default
     )]
-    pub route_text_color: Option<RGB8>,
+    pub text_color: RGB8,
     /// Indicates whether a rider can board the transit vehicle anywhere along the vehicle’s travel path
     #[serde(default)]
     pub continuous_pickup: ContinuousPickupDropOff,
@@ -424,7 +429,7 @@ impl fmt::Display for RawTrip {
 }
 
 /// A Trip is a vehicle that follows a sequence of [StopTime] on certain days. See <https://gtfs.org/reference/static/#tripstxt>
-#[derive(Debug, Default)]
+#[derive(Clone, Debug, Default)]
 pub struct Trip {
     /// Unique technical identifier (not for the traveller) for the Trip
     pub id: String,
@@ -613,7 +618,7 @@ pub struct RawFrequency {
 }
 
 /// Timetables can be defined by the frequency of their vehicles. See <<https://gtfs.org/reference/static/#frequenciestxt>>
-#[derive(Debug, Default)]
+#[derive(Clone, Debug, Default)]
 pub struct Frequency {
     /// Time at which the first vehicle departs from the first stop of the trip
     pub start_time: u32,
@@ -718,3 +723,85 @@ impl fmt::Display for FeedInfo {
         write!(f, "{}", self.name)
     }
 }
+
+/// A graph representation to describe subway or train, with nodes (the locations) and edges (the pathways).
+#[derive(Debug, Serialize, Deserialize, Default)]
+pub struct RawPathway {
+    /// Uniquely identifies the pathway
+    #[serde(rename = "pathway_id")]
+    pub id: String,
+    /// Location at which the pathway begins
+    pub from_stop_id: String,
+    /// Location at which the pathway ends
+    pub to_stop_id: String,
+    /// Type of pathway between the specified (from_stop_id, to_stop_id) pair
+    pub mode: PathwayMode,
+    /// Indicates in which direction the pathway can be used
+    pub is_bidirectional: PathwayDirectionType,
+    /// Horizontal length in meters of the pathway from the origin location to the destination location
+    pub length: Option<f32>,
+    /// Average time in seconds needed to walk through the pathway from the origin location to the destination location
+    pub traversal_time: Option<u32>,
+    /// Number of stairs of the pathway
+    pub stair_count: Option<u32>,
+    /// Maximum slope ratio of the pathway
+    pub max_slope: Option<f32>,
+    /// Minimum width of the pathway in meters
+    pub min_width: Option<f32>,
+    /// String of text from physical signage visible to transit riders
+    pub signposted_as: Option<String>,
+    /// Same than the signposted_as field, but when the pathways is used backward
+    pub reversed_signposted_as: Option<String>,
+}
+
+/// Pathway going from a stop to another.
+#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+pub struct Pathway {
+    /// Uniquely identifies the pathway
+    pub id: String,
+    /// Location at which the pathway ends
+    pub to_stop_id: String,
+    /// Type of pathway between the specified (from_stop_id, to_stop_id) pair
+    pub mode: PathwayMode,
+    /// Indicates in which direction the pathway can be used
+    pub is_bidirectional: PathwayDirectionType,
+    /// Horizontal length in meters of the pathway from the origin location to the destination location
+    pub length: Option<f32>,
+    /// Average time in seconds needed to walk through the pathway from the origin location to the destination location
+    pub traversal_time: Option<u32>,
+    /// Number of stairs of the pathway
+    pub stair_count: Option<u32>,
+    /// Maximum slope ratio of the pathway
+    pub max_slope: Option<f32>,
+    /// Minimum width of the pathway in meters
+    pub min_width: Option<f32>,
+    /// String of text from physical signage visible to transit riders
+    pub signposted_as: Option<String>,
+    /// Same than the signposted_as field, but when the pathways is used backward
+    pub reversed_signposted_as: Option<String>,
+}
+
+impl Id for Pathway {
+    fn id(&self) -> &str {
+        &self.id
+    }
+}
+
+impl From<RawPathway> for Pathway {
+    /// Converts from a [RawPathway] to a [Pathway]
+    fn from(raw: RawPathway) -> Self {
+        Self {
+            id: raw.id,
+            to_stop_id: raw.to_stop_id,
+            mode: raw.mode,
+            is_bidirectional: raw.is_bidirectional,
+            length: raw.length,
+            max_slope: raw.max_slope,
+            min_width: raw.min_width,
+            reversed_signposted_as: raw.reversed_signposted_as,
+            signposted_as: raw.signposted_as,
+            stair_count: raw.stair_count,
+            traversal_time: raw.traversal_time,
+        }
+    }
+}
